summaryrefslogtreecommitdiffstats
path: root/chrome/browser/extensions/extension_install_ui.cc
diff options
context:
space:
mode:
Diffstat (limited to 'chrome/browser/extensions/extension_install_ui.cc')
-rw-r--r--chrome/browser/extensions/extension_install_ui.cc6
1 files changed, 2 insertions, 4 deletions
diff --git a/chrome/browser/extensions/extension_install_ui.cc b/chrome/browser/extensions/extension_install_ui.cc
index e24a5d4..a735efd 100644
--- a/chrome/browser/extensions/extension_install_ui.cc
+++ b/chrome/browser/extensions/extension_install_ui.cc
@@ -225,10 +225,8 @@ void ExtensionInstallUI::ShowThemeInfoBar(const std::string& previous_theme_id,
if (!new_theme->is_theme())
return;
- // Get last active normal browser of profile.
- Browser* browser = BrowserList::FindBrowserWithType(profile,
- Browser::TYPE_NORMAL,
- true);
+ // Get last active tabbed browser of profile.
+ Browser* browser = BrowserList::FindTabbedBrowser(profile, true);
if (!browser)
return;